package Acme::MilkyHolmes::Character::AliceMyojingawa;
use Mouse;
extends 'Acme::MilkyHolmes::Group::MilkyHolmes';

use utf8;

no Mouse;

1;

__DATA__

@@ common
---
color: white
color_enable: 0

@@ en
---
firstname: Alice
familyname: Myojingawa
birthday: June 3
voiced_by: Ayasa Itoh
nickname_voiced_by: ayasa
toys: Bound

@@ ja
---
firstname: アリス
familyname: 明神川
birthday: 6/3
voiced_by: 伊藤 彩沙
nickname_voiced_by: 彩沙
toys: バウンド
