package Acme::MilkyHolmes::Character::CordeliaGlauca;
use Mouse;
extends 'Acme::MilkyHolmes::Group::MilkyHolmes';

use utf8;

no Mouse;

1;

__DATA__

@@ common
color: blue

@@ en
firstname: Cordelia
familyname: Glauca
birthday: December 19
voiced_by: Izumi Kitta
nickname_voiced_by: izusama
toys: Hyper Sensitive

@@ ja
firstname: コーデリア
familyname: グラウカ
birthday: 12/19
voiced_by: 橘田 いずみ
nickname_voiced_by: いず様
toys: ハイパーセンシティブ
name_separator: ・
